@@ -39,7 +39,7 @@
 #' data.example <- data.frame(y1,X)
 #' fit1 <- glg(y1 ~ x1 + x2 - 1,data=data.example)
 #' summary(fit1)
-#' plot(fit1)
+#' deviance_residuals(fit1)
 #'
 #' ###############
 #' #             #
@@ -79,98 +79,98 @@ glg = function(formula, data, shape, Tolerance, Maxiter) {
     if (missingArg(data)) {
         stop("The data argument is missing.")
     }
-    
-    if (missingArg(Tolerance)) 
+
+    if (missingArg(Tolerance))
         Tolerance <- 1e-04
-    if (missingArg(Maxiter)) 
+    if (missingArg(Maxiter))
         Maxiter <- 1000
-    if (missingArg(shape)) 
+    if (missingArg(shape))
         shape <- 1
-    if (class(data) == "list") 
+    if (class(data) == "list")
         data <- as.data.frame(data)
-    
+
     data <- model.frame(formula, data = data)
-    
+
     X <- model.matrix(formula, data = data)
     y <- model.response(data)
     p <- ncol(X)
     n <- nrow(X)
-    
+
     # Initial values
-    
+
     fit0 <- ssym::ssym.l(formula, data = data, family = "Normal")
     beta0 <- coef(fit0)$mu[1:p]
     sigma0 <- exp(coef(fit0)$phi)
     lambda0 <- shape
-    
+
     # Some fixed matrizes
-    
+
     I <- diag(1, n)
     One <- matrix(1, n, 1)
-    
+
     u_lambda <- function(lambd) {
         invlamb <- 1/lambd^2
         output <- (1/lambd) * (digamma(1 + invlamb) - log(invlamb))
         return(output)
     }
-    
+
     v_lambda <- function(lambd) {
         invlamb <- 1/lambd^2
         output <- invlamb * trigamma(1 + invlamb) + u_lambda(lambd)^2
         return(output)
     }
-    
+
     # K_1_lambda and K_2_lambda functions
-    
+
     K_1 <- function(lambd) {
         invlamb2 <- 1/lambd^2
-        part1 <- 4 * (1 + digamma(1 + invlamb2) - digamma(invlamb2) - invlamb2 * 
+        part1 <- 4 * (1 + digamma(1 + invlamb2) - digamma(invlamb2) - invlamb2 *
             trigamma(invlamb2))
         part2 <- trigamma(1 + invlamb2) + (digamma(invlamb2 + 1) - log(invlamb2))^2
         output <- 1 - invlamb2 * (part1 - part2)
         return(output)
     }
-    
+
     K_2 <- function(lambd) {
         invlamb <- 1/lambd
         invlamb2 <- invlamb^2
-        output <- invlamb * ((digamma(1 + invlamb2) - digamma(invlamb2)) - 
+        output <- invlamb * ((digamma(1 + invlamb2) - digamma(invlamb2)) -
             trigamma(1 + invlamb2) - (digamma(1 + invlamb2) - log(invlamb2))^2)
         return(output)
     }
-    
+
     ## Defining the components of the FSIM
-    
+
     I_11 <- function(sigm) {
         output <- (1/(sigm^2)) * t(X) %*% X  # I_1
         return(output)
     }
-    
+
     I_12 <- function(sigm, lambd) {
         output <- (1/(sigm^2)) * u_lambda(lambd) * t(X) %*% One
         return(output)
     }
-    
+
     I_13 <- function(sigm, lambd) {
         output <- (-1/(sigm * lambd)) * u_lambda(lambd) * t(X) %*% One
         return(output)
     }
-    
+
     I_22 <- function(sigm, lambd) {
         output <- (n/(sigm^2)) * (1 + v_lambda(lambd))
         return(output)
     }
-    
+
     I_23 <- function(sigm, lambd) {
         output <- (n/(sigm * lambd^2)) * K_2(lambd)
         return(output)
     }
-    
+
     I_33 <- function(sigm, lambd) {
         output <- (n/(lambd^2)) * K_1(lambd)
         return(output)
     }
-    
+
     I_theta <- function(sigm, lambd) {
         output <- matrix(0, p + 2, p + 2)
         output[1:p, 1:p] = I_11(sigm)
@@ -184,66 +184,66 @@ glg = function(formula, data, shape, Tolerance, Maxiter) {
         output[(p + 2), (p + 2)] = I_33(sigm, lambd)
         return(output)
     }
-    
+
     # SCORE FUNCTIONS
-    
+
     ## Weight matrix for the score functions
-    
+
     ### Defining mu function
-    
+
     mu <- function(bet) {
         output <- X %*% bet
         return(output)
     }
-    
+
     ### First step: The residuals
-    
+
     eps <- function(bet, sigm) {
         epsilon <- (y - mu(bet))/sigm
         return(epsilon)
     }
-    
+
     ### Second step: The matrix D
-    
+
     D <- function(epsilon, lambd) {
         w <- as.vector(exp(lambd * epsilon))
         D_eps <- diag(w)
         return(D_eps)
     }
-    
+
     ### Third step: The matrix W
-    
+
     W <- function(bet, sigm, lambd) {
         output <- I - D(eps(bet, sigm), lambd)
         return(output)
     }
-    
+
     ## Final step: Score functions
-    
+
     U_beta <- function(bet, sigm, lambd) {
-        output <- (-1/(lambd * sigm)) * t(X) %*% W(bet, sigm, lambd) %*% 
+        output <- (-1/(lambd * sigm)) * t(X) %*% W(bet, sigm, lambd) %*%
             One
         return(output)
     }
-    
+
     U_sigma <- function(bet, sigm, lambd) {
-        output <- -(1/sigm) * n - (1/(lambd * sigm)) * t(One) %*% W(bet, 
+        output <- -(1/sigm) * n - (1/(lambd * sigm)) * t(One) %*% W(bet,
             sigm, lambd) %*% eps(bet, sigm)
         return(output)
     }
-    
+
     U_lambda <- function(bet, sigm, lambd) {
         invlamb <- 1/lambd
-        eta_lambd <- (invlamb) * (1 + 2 * (invlamb^2) * (digamma(invlamb^2) + 
+        eta_lambd <- (invlamb) * (1 + 2 * (invlamb^2) * (digamma(invlamb^2) +
             2 * log(abs(lambd)) - 1))
         Ds <- D(eps(bet, sigm), lambd)
         epsilons <- eps(bet, sigm)
-        output <- n * eta_lambd - (invlamb^2) * t(One) %*% epsilons + (2 * 
-            invlamb^3) * t(One) %*% Ds %*% One - (invlamb^2) * t(One) %*% 
+        output <- n * eta_lambd - (invlamb^2) * t(One) %*% epsilons + (2 *
+            invlamb^3) * t(One) %*% Ds %*% One - (invlamb^2) * t(One) %*%
             Ds %*% epsilons
         return(output)
     }
-    
+
     U_theta <- function(bet, sigm, lambd) {
         output <- matrix(1, p + 2, 1)
         output[1:p] <- U_beta(bet, sigm, lambd)
@@ -251,9 +251,9 @@ glg = function(formula, data, shape, Tolerance, Maxiter) {
         output[p + 2] <- U_lambda(bet, sigm, lambd)
         return(output)
     }
-    
+
     ## LOG-LIKELIHOOD
-    
+
     c_l <- function(lambd) {
         if (abs(lambd) < 0.085) {
             if (lambd > 0) {
@@ -268,32 +268,32 @@ glg = function(formula, data, shape, Tolerance, Maxiter) {
         output <- c * (invlambdos^invlambdos)
         return(output)
     }
-    
+
     loglikglg <- function(bet, sigm, lambd) {
         epsilon <- eps(bet, sigm)
-        output <- n * log(c_l(lambd)/sigm) + (1/lambd) * t(One) %*% epsilon - 
+        output <- n * log(c_l(lambd)/sigm) + (1/lambd) * t(One) %*% epsilon -
             (1/lambd^2) * t(One) %*% D(epsilon, lambd) %*% One
         return(output)
     }
-    
+
     ## THE ESTIMATES
-    
+
     newpar <- function(bet, sigm, lambd) {
         output <- matrix(0, p + 2, 2)
         output[1:p, 1] <- bet
         output[p + 1, 1] <- sigm
         output[p + 2, 1] <- lambd
         new <- output[, 1]
-        output[, 2] <- output[, 1] + solve(I_theta(sigm, lambd)) %*% U_theta(bet, 
+        output[, 2] <- output[, 1] + solve(I_theta(sigm, lambd)) %*% U_theta(bet,
             sigm, lambd)
         M = 2
         while (output[p + 1, 2] < 0 & M < Maxiter) {
             output[, 2] = 0.99 * output[, 2] + 0.01 * output[, 1]
             M = M + 1
         }
-        llglg = loglikglg(output[1:p, 2], output[p + 1, 2], output[p + 2, 
+        llglg = loglikglg(output[1:p, 2], output[p + 1, 2], output[p + 2,
             2])
-        condition = llglg - loglikglg(output[1:p, 1], output[p + 1, 1], output[p + 
+        condition = llglg - loglikglg(output[1:p, 1], output[p + 1, 1], output[p +
             2, 1])
         if (condition > 0) {
             new = output[, 2]
@@ -301,8 +301,8 @@ glg = function(formula, data, shape, Tolerance, Maxiter) {
         M = 2
         while (condition < 0 & M < Maxiter) {
             output[, 2] = 0.99 * output[, 2] + 0.01 * output[, 1]
-            condition = loglikglg(output[1:p, 2], output[p + 1, 2], output[p + 
-                2, 2]) - loglikglg(output[1:p, 1], output[p + 1, 1], output[p + 
+            condition = loglikglg(output[1:p, 2], output[p + 1, 2], output[p +
+                2, 2]) - loglikglg(output[1:p, 1], output[p + 1, 1], output[p +
                 2, 1])
             if (condition > 0) {
                 new = output[, 2]
@@ -311,7 +311,7 @@ glg = function(formula, data, shape, Tolerance, Maxiter) {
         }
         return(new)
     }
-    
+
     gfit <- function(resid, lambd) {
         Fs <- ploggamma(resid, lambda = lambd)
         equantil <- qnorm(Fs)
@@ -319,14 +319,14 @@ glg = function(formula, data, shape, Tolerance, Maxiter) {
         output <- mean(abs(diff$x - diff$y))
         return(output)
     }
-    
-    
+
+
     ## THE MAIN FUNCTION
-    
+
     conv <- FALSE
     condition <- 1
     l <- 1
-    
+
     optimum <- function(bet, sigm, lambd) {
         new = matrix(0, p + 2, Maxiter)
         new[, 1] = newpar(bet, sigm, lambd)
@@ -334,20 +334,20 @@ glg = function(formula, data, shape, Tolerance, Maxiter) {
         new[, 2] = newpar(new[1:p, 1], new[(p + 1), 1], new[(p + 2), 1])
         l = 2
         llglg = loglikglg(new[1:p, l], new[(p + 1), l], new[(p + 2), l])
-        condition = llglg - loglikglg(new[1:p, 1], new[p + 1, 1], new[p + 
+        condition = llglg - loglikglg(new[1:p, 1], new[p + 1, 1], new[p +
             2, 1])
         if (condition > 0) {
             output = new[, l]
         }
         while (condition > Tolerance & l < Maxiter) {
             l = l + 1
-            new[, l] = newpar(new[1:p, (l - 1)], new[(p + 1), (l - 1)], new[(p + 
+            new[, l] = newpar(new[1:p, (l - 1)], new[(p + 1), (l - 1)], new[(p +
                 2), (l - 1)])
-            llglg = loglikglg(new[1:p, l], new[(p + 1), l], new[(p + 2), 
+            llglg = loglikglg(new[1:p, l], new[(p + 1), l], new[(p + 2),
                 l])
-            condition = llglg - loglikglg(output[1:p], output[(p + 1)], output[(p + 
+            condition = llglg - loglikglg(output[1:p], output[(p + 1)], output[(p +
                 2)])
-            
+
             if (condition > 0) {
                 output = new[, l]
             }
@@ -361,13 +361,13 @@ glg = function(formula, data, shape, Tolerance, Maxiter) {
             stop("")
         }
     }
-    
+
     output <- optimum(beta0, sigma0, lambda0)
-    
+
     if (abs(output$est[p + 2]) < 0.09) {
         output <- optimum(beta0, sigma0, -lambda0)
     }
-    
+
     if (output$conv == TRUE) {
         conv <- output$conv
         iter <- output$iter
@@ -382,27 +382,27 @@ glg = function(formula, data, shape, Tolerance, Maxiter) {
         ste <- sqrt(diag(solve(covar)))
         zs <- output/ste
         pval <- 1 - (pnorm(abs(zs)) - pnorm(-abs(zs)))
-        y_est <- X %*% output[1:p]
+        mu_est <- X %*% output[1:p]
         ordresidual <- eps(output[1:p], output[p + 1])
-        sgn <- sign(y - y_est)
-        dev <- sgn * sqrt(2) * ((1/output[p + 2]^2) * exp(output[p + 2] * 
-            ordresidual) - (1/output[p + 2]) * ordresidual - (1/output[p + 
+        sgn <- sign(y - mu_est)
+        dev <- sgn * sqrt(2) * ((1/output[p + 2]^2) * exp(output[p + 2] *
+            ordresidual) - (1/output[p + 2]) * ordresidual - (1/output[p +
             2])^2)^(0.5)
         devian <- sum(dev^2)
-        part2 <- ((output[p + 1])/(output[p + 2])) * (digamma((1/output[p + 
+        part2 <- ((output[p + 1])/(output[p + 2])) * (digamma((1/output[p +
             2])^2) - log((1/output[p + 2])^2))
-        y_est <- y_est + part2
+        y_est <- mu_est + part2
         scores <- U_theta(output[1:p], output[p + 1], output[p + 2])
         inter <- matrix(0, p + 2, 2)
         inter[, 1] <- as.matrix(output - 1.96 * ste)
         inter[, 2] <- as.matrix(output + 1.96 * ste)
         good_fit <- gfit(ordresidual, output[p + 2])
-        output <- list(formula = formula, size = n, mu = output[1:p], sigma = output[p + 
-            1], lambda = output[p + 2], y = y, p = p, X = X, Knot = 0, llglg = llglg, 
-            scores = scores, AIC = aic, BIC = bic, AIC2 = aic2, deviance = devian, 
-            rdev = dev, Itheta = covar, st_error = ste, z_values = zs, p.values = pval, 
-            interval = inter, goodnessoffit = good_fit, convergence = conv, 
-            condition = condition, iterations = iter, y_est = y_est, rord = ordresidual, 
+        output <- list(formula = formula, size = n, mu = output[1:p], sigma = output[p +
+            1], lambda = output[p + 2], y = y, p = p, X = X, Knot = 0, llglg = llglg,
+            scores = scores, AIC = aic, BIC = bic, AIC2 = aic2, deviance = devian,
+            rdev = dev, Itheta = covar, st_error = ste, z_values = zs, p.values = pval,
+            interval = inter, goodnessoffit = good_fit, convergence = conv,
+            condition = condition, iterations = iter, mu_est = mu_est, y_est = y_est, rord = ordresidual,
             semi = FALSE, censored = FALSE)
         class(output) = "sglg"
         return(output)
@@ -411,6 +411,6 @@ glg = function(formula, data, shape, Tolerance, Maxiter) {
         print("The optimization was not successful.")
         return(0)
     }
-    
+
 }
 
