@@ -1,7 +1,7 @@
 #'Fitting semi-parametric generalized log-gamma regression models
 #'
-#'\code{sglg} may be used to fit a semi-parametric regression model suitable for analysis of data sets in which the response variable is continuous, strictly positive, and asymmetric.
-#'However, \code{sglg} may also be used to fit data for which the response is asymmetric in the real numbers. In this setup, the location parameter of the response variable is explicitly modeled by semi-parametric functions, whose nonparametric components may be approximated by
+#'\code{sglg} is used to fit a semi-parametric regression model suitable for analysis of data sets in which the response variable is continuous, strictly positive, and asymmetric.
+#'In this setup, the location parameter of the response variable is explicitly modeled by semi-parametric functions, whose nonparametric components may be approximated by
 #'natural cubic splines or cubic P-splines.
 #'
 #' @param formula a symbolic description of the systematic component of the model to be fitted. See details for further information.
@@ -12,6 +12,8 @@
 #' @param shape an optional value for the shape parameter of the error distribution of a generalized log-gamma distribution. Default value is 1.
 #' @param method There are two possibles algorithms to estimate the parameters. The default algorithm is 'FS' Fisher-Scoring,
 #' the other option is 'GSFS' an adequate combination between the block matrix version of non-linear Gauss-Seidel algorithm and Fisher-Scoring algorithm.
+#' @param alpha0 is a vector of initial values for the smoothing parameter alpha.
+#' @param nknts is a vector of the number of knots in each non-linear component of the model.
 #' @param Tolerance an optional positive value, which represents the convergence criterion. Default value is 1e-04.
 #' @param Maxiter an optional positive integer giving the maximal number of iterations for the estimating process. Default value is 1e03.
 
@@ -22,72 +24,29 @@
 #' @return Deviance the deviance associated with the model.
 
 #' @references Carlos A. Cardozo, G. Paula and L. Vanegas. Semi-parametric generalized log-gamma regression models. In preparation.
-#' @references Carlos Alberto Cardozo Delgado, Semi-parametric generalized log-gamma regression models. Ph. D. thesis. Sao Paulo University.
 #' @author Carlos Alberto Cardozo Delgado <cardozorpackages@gmail.com>, G. Paula and L. Vanegas.
 #' @examples
-#' rows <- 175 # Number of observations
-#' columns <- 2 # Number of parametric components
 #' library(ssym)
-#' t_beta  <- c(0.5, 2)
-#' t_sigma <- 1
-#' t_lambda <- 1
-#' t_knot1 <- 7
-#' ts1 <- seq(0, 1, length = t_knot1)
-#' t_g1 <- 0.4 * sin(pi * ts1)
-#'
-#' BasisN <- function(n, knot) {
-#'           N <- matrix(0, n, knot)
-#'           m <- n/knot
-#'           block <- matrix(1, m, 1)
-#'           for (i in 1:knot) {
-#'           l <- (i - 1) * m + 1
-#'           r <- i * m
-#'           N[l:r, i] <- block }
-#'           return(N)
-#'           }
-#' s_N1 <- BasisN(rows, length(ts1))
-#' x3 <- s_N1 %*% ts1
-#' colnames(x3) <- 'x3'
-#' set.seed(8142031)
-#' x1 <- rbinom(rows, 1, 0.5)
-#' x2 <- runif(rows, 0, 1)
-#' X <- cbind(x1,x2)
-#' error <- rglg(rows, 0, 1, t_lambda)
-#' y1 <- X %*%t_beta + + s_N1 %*% t_g1 + t_sigma * error
-#' data.example <- data.frame(y1,X,x3)
-#' fit1 <- sglg(y1 ~ x1 + x2 - 1, npc=x3, method='FS',data=data.example)
-#' fit2 <- sglg(y1 ~ x1 + x2 - 1, npc=x3, method='GSFS',data=data.example)
-#' \dontrun{
-#'
-#' ###########################################
-#' #                                         #
-#' # Diagnostic related grouping system, DRG #
-#' #                                         #
-#' ###########################################
-#'
-#' library(robustloggamma)
-#' library(ssym)
-#' data(drg2000)
-#' attach(drg2000)
-#' LOS2 <-split(LOS,factor(MDC))
-#' MDC2 <-split(Cost,factor(MDC))
-#' y <-log(MDC2$'3')
-#' x <-as.matrix(LOS2$'3')
-#' colnames(x) <- 'LOS'
-#' Data <-data.frame(y,x)
-#' fit1 <-glg(y~LOS,data=Data)
-#' summary(fit1)
-#' fit2 <-sglg(y~1,npc=x,data=Data)
-#' summary(fit2)
-#' plot(fit2)
-#' }
-#'
+#' library(sglg)
+#' set.seed(1)
+#' n <- 200
+#' error <- rglg(n,0,1,1)
+#' x1 <- runif(n,-3,3)
+#' x2 <- rbinom(n,1,0.5)
+#' t <- as.matrix((2*1:n - 1)/(2*n))
+#' colnames(t) <- "t"
+#' f_t <- cos(4*pi*t)
+#' y <- 2*x1 + 0.5*x2 + f_t + error
+#' colnames(y) <- "y"
+#' data <- as.data.frame(cbind(y,x1,x2,t))
+#' fit1 <- sglg(y ~ x1 + x2 - 1,npc=t,data=data,basis = "deBoor")
+#' fit2 <- sglg(y ~ x1 + x2 - 1,npc=t,data=data,basis = "Gu",alpha0=c(0.05,0.1),nknts=7)
 #' @import ssym
 #' @import robustloggamma
 #' @import methods
 #' @export sglg
 
-sglg = function(formula, npc, basis, data, shape, method, Tolerance, Maxiter) {
+sglg = function(formula, npc, basis, data, shape, method, alpha0, nknts, Tolerance, Maxiter) {
     if (missingArg(formula)) {
         stop("The formula argument is missing.")
     }
@@ -119,24 +78,33 @@ sglg = function(formula, npc, basis, data, shape, method, Tolerance, Maxiter) {
 
     p <- ncol(X)
     n <- nrow(X)
-    op1 <- floor(n^(1/3)) + 3
 
-    intknt <- function(x) {
+    k <- dim(npc)[2]
+    Knot <- matrix(0, k, 1)
+    XX <- cbind(X, npc)
+
+    if(missingArg(nknts)){
+      op1 <- floor(n^(1/3))
+      intknt <- function(x) {
         op2 <- length(as.numeric(levels(factor(x))))
         knt <- min(op1, op2)
         if (knt < 3) {
-            stop("This covariate has not at least three different values.")
+          stop("This covariate has not at least three different values.")
         }
         return(knt)
-    }
+      }
 
-    k <- dim(npc)[2]
-    XX <- cbind(X, npc)
-
-    Knot <- matrix(0, k, 1)
-    for (i in 1:k) {
+      for (i in 1:k) {
         Knot[i] <- intknt(XX[, (p + i)])
+      }
     }
+    else{
+      if(min(nknts)>2)
+        Knot <- nknts
+      else
+        stop("Each covariate must have at least three knots.")
+    }
+
 
     Knot <- as.numeric(Knot)
     Tknot <- sum(Knot)
@@ -144,12 +112,16 @@ sglg = function(formula, npc, basis, data, shape, method, Tolerance, Maxiter) {
     K <- matrix(0, p + Tknot, p + Tknot)
 
     for (j in 1:k) {
+      if(basis[j]=="deBoor")
         output <- deBoor2(npc[, j], Knot[j])
-        N <- cbind(N, output$N)
-        Knot1 <- c(0, Knot)
-        l <- p + 1 + sum(Knot1[1:j])
-        r <- p + sum(Knot[1:j])
-        K[l:r, l:r] <- output$K
+      else
+        output <- Gu(npc[, j],Knot[j])
+
+      N <- cbind(N, output$N)
+      Knot1 <- c(0, Knot)
+      l <- p + 1 + sum(Knot1[1:j])
+      r <- p + sum(Knot[1:j])
+      K[l:r, l:r] <- output$K
     }
 
     g0 <- function(knot) {
@@ -183,8 +155,11 @@ sglg = function(formula, npc, basis, data, shape, method, Tolerance, Maxiter) {
     }
 
     fit00 <- ssym::ssym.l(formula3, data = data, family = "Normal")
-    alpha0 <- fit00$lambdas.mu
+    #alpha0 <- fit00$lambdas.mu
 
+    if(missingArg(alpha0)) {
+      alpha0 <- seq(0.1,2,by=0.1)
+    }
     Ident <- diag(1, n)
     Ones <- matrix(1, n, 1)
 
@@ -494,9 +469,14 @@ sglg = function(formula, npc, basis, data, shape, method, Tolerance, Maxiter) {
         return(output)
     }
 
-    opt_alph <- function(alph) {
-        out <- optimize(AIC_p, c(0, alph + 2), tol = 0.001)
-        return(c(out$minimum, out$objective))
+    opt_alph <- function(alph){
+      #alphas <- as.matrix(seq(0.1,alph,by=0.1))
+      alphas <- as.matrix(alph)
+      values <- apply(X=alphas,1,FUN=AIC_p)
+      index_min <- which.min(values)
+      min_val <- alphas[index_min]
+      out <- list(minimum=min_val,objective = values[index_min])
+      return(c(out$minimum, out$objective))
     }
 
     gfit <- function(resid, lambd) {
@@ -556,7 +536,7 @@ sglg = function(formula, npc, basis, data, shape, method, Tolerance, Maxiter) {
             Z_values = zs, p.values = pval, alpha = output1, d.f.model = df,
             d.f.npc = dfnpc, deviance = Devian, goodnessoffit = good_fit,
             convergence = output3$Conv, condition = output3$cond, iterations = output3$iter,
-            semi = TRUE, censored = FALSE, y_est2 = y_est))
+            basis = basis, semi = TRUE, censored = FALSE, mu_est = y_est, y_est = y_est2))
     }
     output <- total_optimum(alpha0)
     class(output) <- "sglg"
