@@ -28,8 +28,7 @@
 #' t_beta  <- c(0.5, 2)
 #' t_sigma <- 0.75
 #' t_lambda <- 1
-
-#' set.seed(8142031)
+#' set.seed(8142030)
 #' library(ssym)
 #' x1 <- rbinom(rows, 1, 0.5)
 #' x2 <- runif(rows, 0, 1)
@@ -55,7 +54,7 @@
 #' colnames(x3) <- 'x3'
 #' sys       <- X %*% t_beta + s_N1%*%t_g1
 #' t_ini1    <- exp(sys) * rweibull(rows,1/t_sigma,1)
-#' cens.time <- rweibull(rows, 1.1, 14)
+#' cens.time <- rweibull(rows, 1.5, 14)
 
 #' delta     <- ifelse(t_ini1 > cens.time, 1, 0)
 #' obst1 = t_ini1
@@ -65,14 +64,13 @@
 #'       }
 #' }
 #' data.example <- data.frame(obst1, delta, X, x3)
-#' fit4  <- ssurvglg(Surv(log(obst1),delta)~ x1 + x2 - 1, npc=x3, data=data.example, shape=0.6)
+#' fit4  <- ssurvglg(Surv(log(obst1),delta)~ x1 + x2 - 1, npc=x3, data=data.example, shape=0.8)
 #' @import ssym
 #' @import robustloggamma
 #' @import methods
 #' @export ssurvglg
 #'
-ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
-    Tolerance) {
+ssurvglg = function(formula, npc, basis, data, shape, Maxiter, Tolerance) {
     if (missingArg(formula)) {
         stop("The formula argument is missing.")
     }
@@ -179,8 +177,7 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
     ### Second step: The matrix D
 
     S = function(t, lambd) {
-        s = pgamma((1/lambd^2) * exp(lambd * t), 1/lambd^2,
-            lower.tail = FALSE)
+        s = pgamma((1/lambd^2) * exp(lambd * t), 1/lambd^2, lower.tail = FALSE)
         return(s)
     }
 
@@ -198,13 +195,11 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         epsil = eps(bet, g, sigm)
         aaa = aa(bet, g, sigm, lambd)
         S = S(epsil, lambd)
-        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) *
-            S)
+        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) * S)
         output = matrix(0, p, 1)
         for (j in 1:p) {
-            output[j] = sum(X[, j] * ((1 - delta) * (1/(lambd *
-                sigm)) * (exp(lambd * epsil) - 1) + delta *
-                (lambd/sigm) * bb))
+            output[j] = sum(X[, j] * ((1 - delta) * (1/(lambd * sigm)) *
+                (exp(lambd * epsil) - 1) + delta * (lambd/sigm) * bb))
         }
         return(output)
     }
@@ -213,13 +208,11 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         epsil = eps(bet, g, sigm)
         aaa = aa(bet, g, sigm, lambd)
         S = S(epsil, lambd)
-        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) *
-            S)
+        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) * S)
         output = matrix(0, p, 1)
         for (j in 1:Knot) {
-            output[j] = sum(N[, j] * ((1 - delta) * (1/(lambd *
-                sigm)) * (exp(lambd * epsil) - 1) + delta *
-                (lambd/sigm) * bb))
+            output[j] = sum(N[, j] * ((1 - delta) * (1/(lambd * sigm)) *
+                (exp(lambd * epsil) - 1) + delta * (lambd/sigm) * bb))
         }
         output = output - alph * K %*% g
         return(output)
@@ -229,10 +222,9 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         epsil = eps(bet, g, sigm)
         aaa = aa(bet, g, sigm, lambd)
         S = S(epsil, lambd)
-        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) *
-            S)
-        part1 = (1/sigm) * (-1 - (1/lambd) * (epsil - epsil *
-            exp(lambd * epsil)))
+        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) * S)
+        part1 = (1/sigm) * (-1 - (1/lambd) * (epsil - epsil * exp(lambd *
+            epsil)))
         part2 = (lambd/sigm) * epsil * bb
         output = sum((1 - delta) * part1 + delta * part2)
         return(output)
@@ -241,8 +233,7 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
     U_theta = function(bet, g, sigm, lambd, alph) {
         output = matrix(1, p + Knot + 1, 1)
         output[1:p] = U_beta(bet, g, sigm, lambd)
-        output[(p + 1):(p + Knot)] = U_g(bet, g, sigm, lambd,
-            alph)
+        output[(p + 1):(p + Knot)] = U_g(bet, g, sigm, lambd, alph)
         output[p + Knot + 1] = U_sigma(bet, g, sigm, lambd)
         return(output)
     }
@@ -253,15 +244,13 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         epsil = eps(bet, g, sigm)
         aaa = aa(bet, g, sigm, lambd)
         S = S(epsil, lambd)
-        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) *
-            S)
+        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) * S)
         output = matrix(0, p, p)
         for (l in 1:p) {
             for (j in 1:p) {
-                output[l, j] = sum(X[, l] * X[, j] * ((1 - delta) *
-                  (-1/sigm^2) * exp(lambd * epsil) + delta *
-                  ((lambd/sigm)^2) * bb * (aaa - 1/lambd^2 -
-                  bb)))
+                output[l, j] = sum(X[, l] * X[, j] * ((1 - delta) * (-1/sigm^2) *
+                  exp(lambd * epsil) + delta * ((lambd/sigm)^2) * bb * (aaa -
+                  1/lambd^2 - bb)))
             }
         }
         return(output)
@@ -271,15 +260,13 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         epsil = eps(bet, g, sigm)
         aaa = aa(bet, g, sigm, lambd)
         S = S(epsil, lambd)
-        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) *
-            S)
+        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) * S)
         output = matrix(0, Knot, Knot)
         for (l in 1:Knot) {
             for (j in 1:Knot) {
-                output[l, j] = sum(N[, l] * N[, j] * ((1 - delta) *
-                  (-1/sigm^2) * exp(lambd * epsil) + delta *
-                  ((lambd/sigm)^2) * bb * (aaa - 1/lambd^2 -
-                  bb)))
+                output[l, j] = sum(N[, l] * N[, j] * ((1 - delta) * (-1/sigm^2) *
+                  exp(lambd * epsil) + delta * ((lambd/sigm)^2) * bb * (aaa -
+                  1/lambd^2 - bb)))
             }
         }
         output = output - alph * K
@@ -288,15 +275,13 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
 
     I_sigma = function(bet, g, sigm, lambd) {
         epsil = eps(bet, g, sigm)
-        part1 = (1/sigm^2) * (1 + (2/lambd) * epsil * (1 - exp(lambd *
-            epsil)) - (epsil^2) * exp(lambd * epsil))
+        part1 = (1/sigm^2) * (1 + (2/lambd) * epsil * (1 - exp(lambd * epsil)) -
+            (epsil^2) * exp(lambd * epsil))
         aaa = aa(bet, g, sigm, lambd)
         S = S(epsil, lambd)
-        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) *
-            S)
+        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) * S)
         b = aaa - (1/lambd^2) - bb/gamma(1/lambd^2)
-        part2 = ((lambd * epsil * bb)/(sigm^2)) * (epsil * b -
-            2/lambd)
+        part2 = ((lambd * epsil * bb)/(sigm^2)) * (epsil * b - 2/lambd)
         output = sum((1 - delta) * part1 + delta * part2)
         return(output)
     }
@@ -305,15 +290,13 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         epsil = eps(bet, g, sigm)
         aaa = aa(bet, g, sigm, lambd)
         S = S(epsil, lambd)
-        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) *
-            S)
+        bb = (aaa^(1/lambd^2) * exp(-aaa))/(gamma(1/lambd^2) * S)
         output = matrix(0, p, Knot)
         for (l in 1:p) {
             for (j in 1:Knot) {
-                output[l, j] = sum(X[, l] * N[, j] * ((1 - delta) *
-                  (-1/sigm^2) * exp(lambd * epsil) + delta *
-                  ((lambd/sigm)^2) * bb * (aaa - 1/lambd^2 -
-                  bb)))
+                output[l, j] = sum(X[, l] * N[, j] * ((1 - delta) * (-1/sigm^2) *
+                  exp(lambd * epsil) + delta * ((lambd/sigm)^2) * bb * (aaa -
+                  1/lambd^2 - bb)))
             }
         }
         return(output)
@@ -324,8 +307,8 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         expep = exp(lambd * epsil)
         H = matrix(0, p, 1)
         for (k in 1:p) {
-            H[k] = sum((1 - delta) * X[, k] * (1 - expep - lambd *
-                epsil * expep))
+            H[k] = sum((1 - delta) * X[, k] * (1 - expep - lambd * epsil *
+                expep))
         }
         part1 = (1/(lambd * (sigm^2))) * H
         part2 = 0 * H
@@ -335,8 +318,7 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         deno = gamma(1/lambd^2) * S
         part21 = -1/lambd + epsil * (aaa - (1/lambd^2) - bb/deno)
         for (k in 1:p) {
-            H[k] = sum(delta * X[, k] * ((((lambd/sigm)^2) *
-                bb/deno) * part21))
+            H[k] = sum(delta * X[, k] * ((((lambd/sigm)^2) * bb/deno) * part21))
         }
         part2 = H
         output = part1 + part2
@@ -348,8 +330,8 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         expep = exp(lambd * epsil)
         H = matrix(0, Knot, 1)
         for (k in 1:Knot) {
-            H[k] = sum((1 - delta) * N[, k] * (1 - expep - lambd *
-                epsil * expep))
+            H[k] = sum((1 - delta) * N[, k] * (1 - expep - lambd * epsil *
+                expep))
         }
         part1 = (1/(lambd * (sigm^2))) * H
         part2 = 0 * H
@@ -359,8 +341,7 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         deno = gamma(1/lambd^2) * S
         part21 = -1/lambd + epsil * (aaa - (1/lambd^2) - bb/deno)
         for (k in 1:Knot) {
-            H[k] = sum(delta * N[, k] * ((((lambd/sigm)^2) *
-                bb/deno) * part21))
+            H[k] = sum(delta * N[, k] * ((((lambd/sigm)^2) * bb/deno) * part21))
         }
         part2 = H
         output = part1 + part2
@@ -371,24 +352,18 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         output = matrix(0, p + Knot + 1, p + Knot + 1)
 
         output[1:p, 1:p] = I_beta(bet, g, sigm, lambd)
-        output[1:p, (p + 1):(p + Knot)] = I_betg(bet, g, sigm,
-            lambd)
-        output[1:p, (p + Knot + 1)] = I_betsig(bet, g, sigm,
-            lambd)
+        output[1:p, (p + 1):(p + Knot)] = I_betg(bet, g, sigm, lambd)
+        output[1:p, (p + Knot + 1)] = I_betsig(bet, g, sigm, lambd)
 
-        output[(p + 1):(p + Knot), 1:p] = t(output[1:p, (p +
-            1):(p + Knot)])
-        output[(p + 1):(p + Knot), (p + 1):(p + Knot)] = I_g(bet,
-            g, sigm, lambd, alph)
-        output[(p + 1):(p + Knot), p + Knot + 1] = I_gsig(bet,
-            g, sigm, lambd)
+        output[(p + 1):(p + Knot), 1:p] = t(output[1:p, (p + 1):(p + Knot)])
+        output[(p + 1):(p + Knot), (p + 1):(p + Knot)] = I_g(bet, g, sigm,
+            lambd, alph)
+        output[(p + 1):(p + Knot), p + Knot + 1] = I_gsig(bet, g, sigm, lambd)
 
-        output[(p + Knot + 1), 1:p] = t(output[1:p, (p + Knot +
-            1)])
-        output[(p + Knot + 1), (p + 1):(p + Knot)] = t(output[(p +
-            1):(p + Knot), p + Knot + 1])
-        output[(p + Knot + 1), (p + Knot + 1)] = I_sigma(bet,
-            g, sigm, lambd)
+        output[(p + Knot + 1), 1:p] = t(output[1:p, (p + Knot + 1)])
+        output[(p + Knot + 1), (p + 1):(p + Knot)] = t(output[(p + 1):(p +
+            Knot), p + Knot + 1])
+        output[(p + Knot + 1), (p + Knot + 1)] = I_sigma(bet, g, sigm, lambd)
 
         return(output)
     }
@@ -417,50 +392,48 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         output[, 1] = c(bet, g, sigm)
         new = output[, 1]
         l = 2
-        output[, l] = output[, (l - 1)] - solve(I_tetha(output[1:p,
-            (l - 1)], output[(p + 1):(p + Knot), (l - 1)], output[(p +
-            Knot + 1), (l - 1)], lambd, alph)) %*% U_theta(output[1:p,
-            (l - 1)], output[(p + 1):(p + Knot), (l - 1)], output[(p +
-            Knot + 1), (l - 1)], lambd, alph)
-        llglg = loglikglg(output[1:p, 2], output[(p + 1):(p +
-            Knot), 2], output[p + Knot + 1, 2], lambd, alph)
-        condition = llglg - loglikglg(new[1:p], new[(p + 1):(p +
-            Knot)], new[p + Knot + 1], lambd, alph)
+        output[, l] = output[, (l - 1)] - solve(I_tetha(output[1:p, (l -
+            1)], output[(p + 1):(p + Knot), (l - 1)], output[(p + Knot +
+            1), (l - 1)], lambd, alph)) %*% U_theta(output[1:p, (l - 1)],
+            output[(p + 1):(p + Knot), (l - 1)], output[(p + Knot + 1), (l -
+                1)], lambd, alph)
+        llglg = loglikglg(output[1:p, 2], output[(p + 1):(p + Knot), 2],
+            output[p + Knot + 1, 2], lambd, alph)
+        condition = llglg - loglikglg(new[1:p], new[(p + 1):(p + Knot)],
+            new[p + Knot + 1], lambd, alph)
 
         if (condition == "NaN") {
-            norm = as.numeric(sqrt(t(U_theta(output[1:p, (l -
-                1)], output[(p + 1):(p + Knot), (l - 1)], output[(p +
-                Knot + 1), (l - 1)], lambd, alph)) %*% U_theta(output[1:p,
-                (l - 1)], output[(p + 1):(p + Knot), (l - 1)],
-                output[(p + Knot + 1), (l - 1)], lambd, alph)))
+            norm = as.numeric(sqrt(t(U_theta(output[1:p, (l - 1)], output[(p +
+                1):(p + Knot), (l - 1)], output[(p + Knot + 1), (l - 1)],
+                lambd, alph)) %*% U_theta(output[1:p, (l - 1)], output[(p +
+                1):(p + Knot), (l - 1)], output[(p + Knot + 1), (l - 1)],
+                lambd, alph)))
             output[, l] = output[, (l - 1)] - (1/norm) * solve(I_tetha(output[1:p,
-                (l - 1)], output[(p + 1):(p + Knot), (l - 1)],
-                output[(p + Knot + 1), (l - 1)], lambd, alph)) %*%
-                U_theta(output[1:p, (l - 1)], output[(p + 1):(p +
-                  Knot), (l - 1)], output[(p + Knot + 1), (l -
-                  1)], lambd, alph)
-            llglg = loglikglg(output[1:p, 2], output[(p + 1):(p +
-                Knot), 2], output[p + Knot + 1, 2], lambd, alph)
-            condition = llglg - loglikglg(new[1:p], new[(p +
-                1):(p + Knot)], new[p + Knot + 1], lambd, alph)
+                (l - 1)], output[(p + 1):(p + Knot), (l - 1)], output[(p +
+                Knot + 1), (l - 1)], lambd, alph)) %*% U_theta(output[1:p,
+                (l - 1)], output[(p + 1):(p + Knot), (l - 1)], output[(p +
+                Knot + 1), (l - 1)], lambd, alph)
+            llglg = loglikglg(output[1:p, 2], output[(p + 1):(p + Knot),
+                2], output[p + Knot + 1, 2], lambd, alph)
+            condition = llglg - loglikglg(new[1:p], new[(p + 1):(p + Knot)],
+                new[p + Knot + 1], lambd, alph)
         }
 
         if (condition < 0) {
-            norm = as.numeric(sqrt(t(U_theta(output[1:p, (l -
-                1)], output[(p + 1):(p + Knot), (l - 1)], output[(p +
-                Knot + 1), (l - 1)], lambd, alph)) %*% U_theta(output[1:p,
-                (l - 1)], output[(p + 1):(p + Knot), (l - 1)],
-                output[(p + Knot + 1), (l - 1)], lambd, alph)))
+            norm = as.numeric(sqrt(t(U_theta(output[1:p, (l - 1)], output[(p +
+                1):(p + Knot), (l - 1)], output[(p + Knot + 1), (l - 1)],
+                lambd, alph)) %*% U_theta(output[1:p, (l - 1)], output[(p +
+                1):(p + Knot), (l - 1)], output[(p + Knot + 1), (l - 1)],
+                lambd, alph)))
             output[, l] = output[, (l - 1)] - (1/norm) * solve(I_tetha(output[1:p,
-                (l - 1)], output[(p + 1):(p + Knot), (l - 1)],
-                output[(p + Knot + 1), (l - 1)], lambd, alph)) %*%
-                U_theta(output[1:p, (l - 1)], output[(p + 1):(p +
-                  Knot), (l - 1)], output[(p + Knot + 1), (l -
-                  1)], lambd, alph)
-            llglg = loglikglg(output[1:p, 2], output[(p + 1):(p +
-                Knot), 2], output[p + Knot + 1, 2], lambd, alph)
-            condition = llglg - loglikglg(new[1:p], new[(p +
-                1):(p + Knot)], new[p + Knot + 1], lambd, alph)
+                (l - 1)], output[(p + 1):(p + Knot), (l - 1)], output[(p +
+                Knot + 1), (l - 1)], lambd, alph)) %*% U_theta(output[1:p,
+                (l - 1)], output[(p + 1):(p + Knot), (l - 1)], output[(p +
+                Knot + 1), (l - 1)], lambd, alph)
+            llglg = loglikglg(output[1:p, 2], output[(p + 1):(p + Knot),
+                2], output[p + Knot + 1, 2], lambd, alph)
+            condition = llglg - loglikglg(new[1:p], new[(p + 1):(p + Knot)],
+                new[p + Knot + 1], lambd, alph)
         }
 
         if (condition > 0) {
@@ -480,7 +453,8 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
 
         diff = abs(r_q - qnorm(Fkm))
         output = mean(diff[-length(diff)])
-        return(output)
+        msurv <- 1 - Fs
+        return(list(stat=output,msurv = msurv))
     }
 
     ## THE MAIN FUNCTION
@@ -496,14 +470,13 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         output = new[, 1]
 
         l = 2
-        new[, l] = newpar(new[1:p, (l - 1)], new[(p + 1):(p +
-            Knot), (l - 1)], new[(p + Knot + 1), (l - 1)], lambd,
-            alph)
+        new[, l] = newpar(new[1:p, (l - 1)], new[(p + 1):(p + Knot), (l -
+            1)], new[(p + Knot + 1), (l - 1)], lambd, alph)
 
-        llglg = loglikglg(new[1:p, l], new[(p + 1):(p + Knot),
-            l], new[(p + Knot + 1), l], lambd, alph)
-        condition = llglg - loglikglg(output[1:p], output[(p +
-            1):(p + Knot)], output[p + Knot + 1], lambd, alph)
+        llglg = loglikglg(new[1:p, l], new[(p + 1):(p + Knot), l], new[(p +
+            Knot + 1), l], lambd, alph)
+        condition = llglg - loglikglg(output[1:p], output[(p + 1):(p + Knot)],
+            output[p + Knot + 1], lambd, alph)
 
         if (condition > 0) {
             output = new[, l]
@@ -511,25 +484,23 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
 
         while (condition > Tolerance & l < Maxiter) {
             l = l + 1
-            new[, l] = newpar(new[1:p, (l - 1)], new[(p + 1):(p +
-                Knot), (l - 1)], new[(p + Knot + 1), (l - 1)],
-                lambd, alph)
-            llglg = loglikglg(new[1:p, l], new[(p + 1):(p +
-                Knot), l], new[(p + Knot + 1), l], lambd, alph)
+            new[, l] = newpar(new[1:p, (l - 1)], new[(p + 1):(p + Knot),
+                (l - 1)], new[(p + Knot + 1), (l - 1)], lambd, alph)
+            llglg = loglikglg(new[1:p, l], new[(p + 1):(p + Knot), l], new[(p +
+                Knot + 1), l], lambd, alph)
 
-            condition = llglg - loglikglg(output[1:p], output[(p +
-                1):(p + Knot)], output[(p + Knot + 1)], lambd,
-                alph)
+            condition = llglg - loglikglg(output[1:p], output[(p + 1):(p +
+                Knot)], output[(p + Knot + 1)], lambd, alph)
 
             if (condition > 0) {
                 output = new[, l]
-                llglg = loglikglg(output[1:p], output[(p + 1):(p +
-                  Knot)], output[(p + Knot + 1)], lambd, alph)
+                llglg = loglikglg(output[1:p], output[(p + 1):(p + Knot)],
+                  output[(p + Knot + 1)], lambd, alph)
             }
         }
         if (l < Maxiter) {
-            return(list(est = output, llglg = llglg, cond = condition,
-                conv = TRUE, iter = l))
+            return(list(est = output, llglg = llglg, cond = condition, conv = TRUE,
+                iter = l))
         }
         if (l >= Maxiter) {
             stop("The convergence was not successful.")
@@ -537,8 +508,8 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
     }
 
     edf = function(bet, g, sigm, lambd, alph) {
-        output = sum(diag((1/sigm^2) * t(N) %*% N %*% solve(-I_g(bet,
-            g, sigm, lambd, alph))))
+        output = sum(diag((1/sigm^2) * t(N) %*% N %*% solve(-I_g(bet, g,
+            sigm, lambd, alph))))
         return(output)
     }
 
@@ -552,13 +523,12 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
             num.iter = news$iter
             cond = news$cond
             llglg = news$llglg
-            df = edf(news$est[1:p], news$est[(p + 1):(p + Knot)],
-                news$est[(p + Knot + 1)], lambda0, alph)
+            df = edf(news$est[1:p], news$est[(p + 1):(p + Knot)], news$est[(p +
+                Knot + 1)], lambda0, alph)
             aic = -2 * llglg + 2 * (p + df + 1)
             bic = -2 * llglg + log(n) * (p + df + 1)
-            return(list(est = news$est, df = df, llglg = llglg,
-                AIC = aic, BIC = bic, Conv = Conv, iter = num.iter,
-                cond = cond))
+            return(list(est = news$est, df = df, llglg = llglg, AIC = aic,
+                BIC = bic, Conv = Conv, iter = num.iter, cond = cond))
         }
         if (news$iter >= Maxiter) {
             Conv = FALSE
@@ -592,47 +562,43 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
         d.f.npc <- df - p
         output <- output3$est
         llglg <- output3$llglg
-        aic = output3$AIC
-        bic = output3$BIC
-        scores = U_theta(output[1:p], output[(p + 1):(p + Knot)],
-            output[p + Knot + 1], lambda0, output1)
-        covar = I_tetha(output[1:p], output[(p + 1):(p + Knot)],
-            output[p + Knot + 1], lambda0, output1)
-        inter = matrix(0, p + Knot + 1, 2)
-        scovar = solve(-covar)
-        val = diag(scovar)
+        aic <- output3$AIC
+        bic <- output3$BIC
+        scores <- U_theta(output[1:p], output[(p + 1):(p + Knot)], output[p +
+            Knot + 1], lambda0, output1)
+        covar <- I_tetha(output[1:p], output[(p + 1):(p + Knot)], output[p +
+            Knot + 1], lambda0, output1)
+        inter <- matrix(0, p + Knot + 1, 2)
+        scovar <- solve(-covar)
+        val <- diag(scovar)
         # if (min(val) > 0) {
-        ste = sqrt(val)
-        inter[, 1] = as.matrix(output - 1.96 * ste)
-        inter[, 2] = as.matrix(output + 1.96 * ste)
-        zs = abs(output/ste)
-        pval = 1 - (pnorm(zs) - pnorm(-zs))
-        pval2 = pval[-((p + 1):(p + Knot))]
-        as = output[(p + 1):(p + Knot)]
+        ste <- sqrt(val)
+        inter[, 1] <- as.matrix(output - 1.96 * ste)
+        inter[, 2] <- as.matrix(output + 1.96 * ste)
+        zs <- abs(output/ste)
+        pval <- 1 - (pnorm(zs) - pnorm(-zs))
+        pval2 <- pval[-((p + 1):(p + Knot))]
+        as <- output[(p + 1):(p + Knot)]
         # }
-        y_est = X %*% output[1:p] + N %*% output[(p + 1):(p +
-            Knot)]
-        ordresidual = eps(output[1:p], output[(p + 1):(p + Knot)],
-            output[p + Knot + 1])
-        sgn = sign(Y[, 1] - y_est)
-        outputp = lambda0
-        dev = sgn * sqrt(2) * ((1 - delta) * ((1/outputp^2) *
-            exp(outputp * ordresidual) - (1/outputp) * ordresidual -
-            (1/outputp)^2)^(0.5) + delta * (-log(S(ordresidual,
-            outputp))))
-        devian = sum(dev^2)
-        part2 = ((output[p + 1])/outputp) * (digamma((1/outputp)^2) -
-            log((1/outputp)^2))
-        y_est = y_est + part2
-        good_fit = gfit(ordresidual, outputp)
-        output = list(formula = formula, npc = npc, size = n,
-            per.cens = per.censo, mu = output[1:(p + Knot)],
-            sigma = output[p + Knot + 1], lambda = lambda0,
-            alpha = output1, edf = df, d.f.npc = d.f.npc, y = Y[,
-                1], delta = delta, X = X, N = N, p = p, Knot = Knot,
-            y_est = y_est, rord = ordresidual, rdev = dev, scores = scores,
-            deviance = devian, goodnessoffit = good_fit, llglg = llglg,
-            AIC = aic, BIC = bic, scovar = scovar, st_error = ste,
+        y_est <- X %*% output[1:p] + N %*% output[(p + 1):(p + Knot)]
+        ordresidual <- eps(output[1:p], output[(p + 1):(p + Knot)], output[p +
+            Knot + 1])
+        sgn <- sign(Y[, 1] - y_est)
+        outputp <- lambda0
+        dev <- sgn * sqrt(2) * ((1 - delta) * ((1/outputp^2) * exp(outputp *
+            ordresidual) - (1/outputp) * ordresidual - (1/outputp)^2)^(0.5) +
+            delta * (-log(S(ordresidual, outputp))))
+        devian <- sum(dev^2)
+        part2 <- ((output[p + 1])/outputp) * (digamma((1/outputp)^2) - log((1/outputp)^2))
+        y_est <- y_est + part2
+        good_fit <- gfit(ordresidual, outputp)
+        msurv <- good_fit$msurv
+        output <- list(formula = formula, npc = npc, size = n, per.cens = per.censo,
+            mu = output[1:(p + Knot)], sigma = output[p + Knot + 1], lambda = lambda0,
+            alpha = output1, edf = df, d.f.npc = d.f.npc, y = Y[, 1], delta = delta,
+            X = X, N = N, p = p, Knot = Knot, y_est = y_est, rord = ordresidual,
+            rdev = dev, scores = scores, deviance = devian,  modelsurv=msurv, goodnessoffit = good_fit$stat,
+            llglg = llglg, AIC = aic, BIC = bic, scovar = scovar, st_error = ste,
             p.values = pval2, convergence = output3$Conv, condition = output3$cond,
             Iterations = output3$iter, semi = TRUE, censored = TRUE)
         return(output)
@@ -642,5 +608,3 @@ ssurvglg = function(formula, npc, basis, data, shape, Maxiter,
     return(output)
 }
 
-# , st_error = ste z_values = zs,
-#' interval = inter
